@@ -1,4 +1,4 @@
-//! Analysis tools from the Etherem Toolkit.
+//! Analysis tools from the Ethereum Toolkit.
 //!
 //! Highly unstable and incomplete.
 
@@ -7,5 +7,6 @@
 // TODO: #![deny(unreachable_pub)]
 #![deny(missing_debug_implementations)]
 
-pub mod blocks;
+mod blocks;
+pub mod cfg;
 mod sym;
